import pino from 'pino';
import { Transform } from 'stream';
import type { Run } from '../run/types';
export declare const RegisteredLogger: {
    readonly AGENT: "AGENT";
    readonly WORKFLOW: "WORKFLOW";
    readonly LLM: "LLM";
    readonly TTS: "TTS";
    readonly VECTOR: "VECTOR";
    readonly DEPLOYER: "DEPLOYER";
    readonly ENGINE: "ENGINE";
    readonly MEMORY: "MEMORY";
};
export type RegisteredLogger = (typeof RegisteredLogger)[keyof typeof RegisteredLogger];
export declare const LogLevel: {
    readonly DEBUG: "debug";
    readonly INFO: "info";
    readonly WARN: "warn";
    readonly ERROR: "error";
    readonly NONE: "silent";
};
export type LogLevel = (typeof LogLevel)[keyof typeof LogLevel];
export interface BaseLogMessage extends Run {
    message: string;
    destinationPath: string;
    type: RegisteredLogger;
}
export declare class LoggerTransport extends Transform {
    getLogsByRunId({ runId }: {
        runId: string;
    }): Promise<BaseLogMessage[]>;
    getLogs(): Promise<BaseLogMessage[]>;
}
type TransportMap = Record<string, LoggerTransport>;
export declare class Logger {
    protected logger: pino.Logger;
    transports: TransportMap;
    constructor(options?: {
        name?: string;
        level?: LogLevel;
        transports?: TransportMap;
        overrideDefaultTransports?: boolean;
    });
    debug(message: string, args?: Record<string, any>): void;
    info(message: string, args?: Record<string, any>): void;
    warn(message: string, args?: Record<string, any>): void;
    error(message: string, args?: Record<string, any>): void;
    createStream(): Transform;
    getLogs(transportId: string): Promise<BaseLogMessage[]>;
    getLogsByRunId({ runId, transportId }: {
        transportId: string;
        runId: string;
    }): Promise<BaseLogMessage[] | undefined>;
}
export declare function createLogger(options: {
    name?: string;
    level?: LogLevel;
    transports?: TransportMap;
}): Logger;
export declare class MultiLogger {
    private loggers;
    constructor(loggers: Logger[]);
    debug(message: string, ...args: any[]): void;
    info(message: string, ...args: any[]): void;
    warn(message: string, ...args: any[]): void;
    error(message: string, ...args: any[]): void;
}
export declare function combineLoggers(loggers: Logger[]): MultiLogger;
export declare const noopLogger: {
    debug: () => void;
    info: () => void;
    warn: () => void;
    error: () => void;
    cleanup: () => Promise<void>;
};
export {};
//# sourceMappingURL=index.d.ts.map