import { z } from 'zod';
import 'dotenv/config';
import { Agent } from '../agent';
import { MastraDeployer } from '../deployer';
import { MastraEngine } from '../engine';
import { LLM } from '../llm';
import { ModelConfig } from '../llm/types';
import { Logger } from '../logger';
import { MastraMemory } from '../memory';
import { Run } from '../run/types';
import { SyncAction } from '../sync';
import { OtelConfig, Telemetry } from '../telemetry';
import { MastraTTS } from '../tts';
import { MastraVector } from '../vector';
import { Workflow } from '../workflows';
import { StripUndefined } from './types';
export declare class Mastra<TSyncs extends Record<string, SyncAction<any, any, any, any>> = Record<string, SyncAction<any, any, any, any>>, TAgents extends Record<string, Agent<any>> = Record<string, Agent<any>>, TWorkflows extends Record<string, Workflow> = Record<string, Workflow>, TVectors extends Record<string, MastraVector> = Record<string, MastraVector>, TTTS extends Record<string, MastraTTS> = Record<string, MastraTTS>, TLogger extends Logger = Logger> {
    private vectors?;
    private agents;
    private logger;
    private syncs;
    private workflows;
    private telemetry?;
    private tts?;
    private deployer?;
    engine?: MastraEngine;
    memory?: MastraMemory;
    constructor(config?: {
        memory?: MastraMemory;
        syncs?: TSyncs;
        agents?: TAgents;
        engine?: MastraEngine;
        vectors?: TVectors;
        logger?: TLogger | false;
        workflows?: TWorkflows;
        tts?: TTTS;
        telemetry?: OtelConfig;
        deployer?: MastraDeployer;
    });
    LLM(modelConfig: ModelConfig): LLM;
    sync<K extends keyof TSyncs>(key: K, params: TSyncs[K] extends SyncAction<any, infer TSchemaIn, any, any> ? TSchemaIn extends z.ZodSchema ? z.infer<TSchemaIn> : never : never, runId?: Run['runId']): Promise<StripUndefined<TSyncs[K]['outputSchema']>['_input']>;
    getAgent<TAgentName extends keyof TAgents>(name: TAgentName): TAgents[TAgentName];
    getAgents(): TAgents;
    getVector<TVectorName extends keyof TVectors>(name: TVectorName): TVectors[TVectorName];
    getVectors(): TVectors | undefined;
    getDeployer(): MastraDeployer | undefined;
    getWorkflow<TWorkflowId extends keyof TWorkflows>(id: TWorkflowId, { serialized }?: {
        serialized?: boolean;
    }): TWorkflows[TWorkflowId];
    getWorkflows(props?: {
        serialized?: boolean;
    }): Record<string, Workflow>;
    setLogger({ logger }: {
        logger: TLogger;
    }): void;
    getLogger(): TLogger;
    getTelemetry(): Telemetry | undefined;
    getLogsByRunId({ runId, transportId }: {
        runId: string;
        transportId: string;
    }): Promise<import("..").BaseLogMessage[] | undefined>;
    getLogs(transportId: string): Promise<import("..").BaseLogMessage[]>;
}
//# sourceMappingURL=index.d.ts.map